==> nextcloud-20.0.12.tgz: nextcloud/apps/dashboard/l10n/mk.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Табла",
    "Dashboard app" : "Табла",
    "Show something" : "Прикажи нешто",
    "Customize" : "Прилагоди",
    "Edit widgets" : "Уреди графички контроли",
    "Change background image" : "Промени ја позадинската слика",
    "Weather service" : "Сервис за временска прогноза",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "За ваша приватност, податоците за времето ги бара вашиот сервер во ваше име, така што метеоролошката служба не добива лични информации.",
    "Weather data from Met.no" : "Податоци за временето од Met.no",
    "geocoding with Nominatim" : "Геокодирање со Nominatim",
    "elevation data from OpenTopoData" : "Податоци за височина од OpenTopoData",
    "Weather" : "Временска прогноза",
    "Status" : "Статус",
    "Good morning" : "Добро утро",
    "Good morning, {name}" : "Добро утро, {name}",
    "Good afternoon" : "Добар ден",
    "Good afternoon, {name}" : "Добар ден, {name}",
    "Good evening" : "Добровечер",
    "Good evening, {name}" : "Добровечер, {name}",
    "Hello" : "Здраво",
    "Hello, {name}" : "Здраво, {name}",
    "Pick from Files" : "Избери од датотеките",
    "Default images" : "Стандардни слики",
    "Plain background" : "Обична позадина",
    "Insert from {productName}" : "Вметнни од {productName}",
    "Get more widgets from the app store" : "Преземи повеќе графички контроли од продавницата со апликации",
    "Good night, {name}" : "Добра ноќ, {name}",
    "Good night" : "Добра ноќ",
    "Pick from files" : "Избери од датотеките"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-20.0.13.tgz: nextcloud/apps/dashboard/l10n/mk.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Табла",
    "Dashboard app" : "Табла",
    "Show something" : "Прикажи нешто",
    "Customize" : "Прилагоди",
    "Edit widgets" : "Уреди графички контроли",
    "Get more widgets from the App Store" : "Преземи повеќе графички контроли од продавницата со апликации",
    "Change background image" : "Промени ја позадинската слика",
    "Weather service" : "Сервис за временска прогноза",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "За ваша приватност, податоците за времето ги бара вашиот сервер во ваше име, така што метеоролошката служба не добива лични информации.",
    "Weather data from Met.no" : "Податоци за временето од Met.no",
    "geocoding with Nominatim" : "Геокодирање со Nominatim",
    "elevation data from OpenTopoData" : "Податоци за височина од OpenTopoData",
    "Weather" : "Временска прогноза",
    "Status" : "Статус",
    "Good morning" : "Добро утро",
    "Good morning, {name}" : "Добро утро, {name}",
    "Good afternoon" : "Добар ден",
    "Good afternoon, {name}" : "Добар ден, {name}",
    "Good evening" : "Добровечер",
    "Good evening, {name}" : "Добровечер, {name}",
    "Hello" : "Здраво",
    "Hello, {name}" : "Здраво, {name}",
    "Pick from Files" : "Избери од датотеките",
    "Default images" : "Стандардни слики",
    "Plain background" : "Обична позадина",
    "Insert from {productName}" : "Вметнни од {productName}",
    "Get more widgets from the app store" : "Преземи повеќе графички контроли од продавницата со апликации",
    "Good night, {name}" : "Добра ноќ, {name}",
    "Good night" : "Добра ноќ",
    "Pick from files" : "Избери од датотеките"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
